spacepy.irbempy.find_Bmirror — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »

# spacepy.irbempy.find_Bmirror

`spacepy.irbempy.` `find_Bmirror`(ticks, loci, alpha, extMag='T01STORM', options=[1, 0, 0, 0, 0], omnivals=None)

  call find_mirror_point from irbem library and return a dictionary with values for Blocal, Bmirr and the GEO (cartesian) coordinates of the mirror point

  Parameters: | ticks : Ticktock class containing time information loci : Coords class containing spatial information alpha : array-like containing the pitch angles extMag : str optional; will choose the external magnetic field model possible values [‘0’, ‘MEAD’, ‘T87SHORT’, ‘T87LONG’, ‘T89’, OPQUIET’, ‘OPDYN’, ‘T96’, ‘OSTA’, ‘T01QUIET’, ‘T01STORM’, ‘T05’, ‘ALEX’] options : array-like (optional) length=5 : explained in Lstar omnivals : dict (optional) if not provided, will use lookup table (see get_Lstar documentation for further explanation)
  Returns: | results : dictionary containing keys: Blocal, Bmirr, GEOcar

  See also

  `get_Lstar`, `get_Bfield`, `find_magequator`

  Examples

      >>> t = Ticktock(['2002-02-02T12:00:00', '2002-02-02T12:10:00'], 'ISO')
      >>> y = Coords([[3,0,0],[2,0,0]], 'GEO', 'car')
      >>> ib.find_Bmirror(t,y,[90,80,60,10])
      {'Blocal': array([ 0.,  0.]),
          'Bmirr': array([ 0.,  0.]),
          'loci': Coords( [[ NaN  NaN  NaN]
          [ NaN  NaN  NaN]] ), dtype=GEO,car, units=['Re', 'Re', 'Re']}

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »